@@ -340,44 +340,3 @@ bluetooth_send_to_address (const char *address,
 	g_ptr_array_free (a, TRUE);
 }
 
-typedef struct {
-  GSimpleAsyncResult *result;
-  guint timestamp;
-} MountClosure;
-
-static void
-mount_ready_cb (GObject *object,
-		GAsyncResult *result,
-		gpointer user_data)
-{
-	GError *error = NULL;
-	GFile *file = G_FILE (object);
-	char *uri = g_file_get_uri (file);
-	MountClosure *closure = user_data;
-
-	if (g_file_mount_enclosing_volume_finish (file, result, &error) == FALSE) {
-		/* Ignore "already mounted" error */
-		if (error->domain == G_IO_ERROR &&
-		    error->code == G_IO_ERROR_ALREADY_MOUNTED) {
-			g_error_free (error);
-			error = NULL;
-		}
-	}
-
-	if (!error) {
-		gtk_show_uri (NULL, uri, closure->timestamp, &error);
-	}
-
-	if (error) {
-		g_simple_async_result_set_from_error (closure->result, error);
-		g_error_free (error);
-	} else {
-		g_simple_async_result_set_op_res_gboolean (closure->result, TRUE);
-	}
-
-	g_simple_async_result_complete (closure->result);
-
-	g_free (uri);
-	g_object_unref (closure->result);
-	g_free (closure);
-}
